Crate cheap_alerts

A library for sending notifications via email. If you need a quick and dirty way to send out notifications (and you have access to an email server), this crate is for you!

Structs

ClientTlsParameters
Parameters to use for secure clients
Destination
A phone number and mobile carrier pair for sending a text message
Sender
SenderBuilder
A builder for easily creating a Sender
SmtpClient
Contains client configuration

Enums

Carrier
A cell phone carrier
ClientSecurity
How to apply TLS to a client connection
Error